@@ -7,6 +7,7 @@ import copy
 from abc import ABC, abstractmethod
 from datetime import datetime
 from functools import lru_cache
+from itertools import tee
 from typing import Any, Dict, Iterator, List, Mapping, MutableMapping, Optional, Tuple
 
 from airbyte_cdk.logger import AirbyteLogger
@@ -177,14 +178,9 @@ class AbstractSource(Source, ABC):
                 cursor_field=configured_stream.cursor_field or None,
             )
 
-            logger.info(f"records number: {list(records)}")
+            records, second_iter = tee(records)
 
-            logger.info(f"records first: {list(records)[0]}")
-            logger.info(f"records status: {not list(records)}")
-
-
-            if not list(records):
-                logger.info(f"came inside: {type(records)}")
+            if not list(second_iter):
                 stream_state = stream_instance.get_updated_state_empty(stream_state, slice)
 
             for record_counter, record_data in enumerate(records, start=1):
